aboutsummaryrefslogtreecommitdiffstats
path: root/src/net/java
diff options
context:
space:
mode:
authorEmil Ivov <emcho@jitsi.org>2006-10-23 16:23:27 +0000
committerEmil Ivov <emcho@jitsi.org>2006-10-23 16:23:27 +0000
commit47e5eb72c3a8b8dcfadc15c8a22e96ea441d1af6 (patch)
treef9fbef730f5f0a5edcc68b3f5a7cacb8298f213b /src/net/java
parent72175cf38db27b7fb7e75e29a8cea1f5e2ee1d91 (diff)
downloadjitsi-47e5eb72c3a8b8dcfadc15c8a22e96ea441d1af6.zip
jitsi-47e5eb72c3a8b8dcfadc15c8a22e96ea441d1af6.tar.gz
jitsi-47e5eb72c3a8b8dcfadc15c8a22e96ea441d1af6.tar.bz2
Working on the JMF implementation of the media service.
Added a method for retrieving a public address for a port (without specifying an intended destination), in which case we will be using the address of our stun server as a destination.
Diffstat (limited to 'src/net/java')
-rw-r--r--src/net/java/sip/communicator/service/netaddr/NetworkAddressManagerService.java17
1 files changed, 14 insertions, 3 deletions
diff --git a/src/net/java/sip/communicator/service/netaddr/NetworkAddressManagerService.java b/src/net/java/sip/communicator/service/netaddr/NetworkAddressManagerService.java
index 7e028a9..12d22bf 100644
--- a/src/net/java/sip/communicator/service/netaddr/NetworkAddressManagerService.java
+++ b/src/net/java/sip/communicator/service/netaddr/NetworkAddressManagerService.java
@@ -50,14 +50,25 @@ public interface NetworkAddressManagerService
* STUN lib fails, tries to retrieve localhost, if that fails too, returns
* null.
*
* @param indendedDestination the destination that we'd like to use this
* address with.
* @param port the port whose mapping we are interested in.
* @return a public address corresponding to the specified port or null if
* all attempts to retrieve such an address have failed.
*/
- public InetSocketAddress getPublicAddressFor(InetAddress indendedDestination,
- int port);
+ public InetSocketAddress getPublicAddressFor(
+ InetAddress intendedDestination,
+ int port);
+
+ /**
+ * Tries to obtain a mapped/public address for the specified port (possibly
+ * by executing a STUN query).
+ *
+ * @param port the port whose mapping we are interested in.
+ * @return a public address corresponding to the specified port or null
+ * if all attempts to retrieve such an address have failed.
+ */
+ public InetSocketAddress getPublicAddressFor(int port);
/**
* Initializes the network address manager service implementation and
@@ -50,14 +50,25 @@ public interface NetworkAddressManagerService
* null.
*
- * @param indendedDestination the destination that we'd like to use this
+ * @param intendedDestination the destination that we'd like to use this
* address with.
* @param port the port whose mapping we are interested in.